"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const semver = require("resin-semver");
const VALID_INCREMENT_LEVELS = ['patch', 'minor', 'major'];
exports.isValidIncrementLevel = (level) => {
    return _.includes(VALID_INCREMENT_LEVELS, level);
};
exports.getHigherIncrementLevel = (firstLevel, secondLevel) => {
    _.each([firstLevel, secondLevel], level => {
        if (level != null && !exports.isValidIncrementLevel(level)) {
            throw new Error(`Invalid increment level: ${level}`);
        }
    });
    if (!firstLevel && !secondLevel) {
        return null;
    }
    const firstLevelIndex = _.indexOf(VALID_INCREMENT_LEVELS, firstLevel);
    const secondLevelIndex = _.indexOf(VALID_INCREMENT_LEVELS, secondLevel);
    return VALID_INCREMENT_LEVELS[Math.max(firstLevelIndex, secondLevelIndex)];
};
exports.calculateNextIncrementLevel = (commits, options) => {
    if (_.isEmpty(commits)) {
        throw new Error('No commits to calculate the next increment level from');
    }
    return _.reduce(commits, (currentLevel, commit) => {
        const commitLevel = options.getIncrementLevelFromCommit(commit);
        return exports.getHigherIncrementLevel(commitLevel, currentLevel);
    }, null);
};
exports.checkValid = (version) => {
    if (!semver.valid(version)) {
        throw new Error(`Invalid version: ${version}`);
    }
    return true;
};
exports.getGreaterVersion = (versions) => {
    return _.first(versions
        .map(v => {
        return v.trim();
    })
        .sort(semver.rcompare));
};
__export(require("resin-semver"));
//# sourceMappingURL=semver.js.map